# bcmf_rundietbc_1.R


RUN_Dietary_BoxCox <- function(testfile.csvy) {
  
  # title and program version
  cat("\nRUN DIETARY (BoxCox-transformed). Version:", PROG.Version, "\n")

  
  # --- READ DIETARY TEST DATA

  # read aqueous test data from a .csvy file
  cat("\nDIETARY TEST READ: ", testfile.csvy, "\n\n")
  print(readTest_Dietary(testfile.csvy))

  # show the test conditions
  cat("\nTEST.Dietary.Param: \n\n")
  print(TEST.Dietary.Param)

  
  # --- FIT UNTRANSFORMED MODEL FIRST

  cat("\nMODEL FIT (untransformed):\n\n")
  print(fitModel_Dietary())
  
  
  # --- FIT BMF MODEL BC-TRANSFORMED & DIAGNOSTICS

  # BoxCox profile plot, lambda estimates
  lambdaestimate <- modelTrans_BoxCox_Dietary()
  
  cat("\nLAMBDA FIT & CONFIDENCE INTERVAL:\n\n")
  print(lambdaestimate)
  
  # take fit as best estimate
  lambdabest <- lambdaestimate["fit"]
  
  # fit BC-transformed
  cat("\nMODEL FIT (BoxCox-transformed):\n\n")
  print(fitModel_Dietary_BoxCox(lambda = lambdabest))

  # check model diagnostics
  cat("\nMODEL DIAGNOSTICS (BoxCox-transformed):\n")
  print(modelDiag_Dietary_BoxCox())
  
  
  # --- PLOT BEST FIT BC-TRANSFORMED & ORIGINAL SCALE

  # calculate best fit on BC-transformed scale
  runBestFit_Dietary_BoxCox()

  # plot best BC-fit on BC-transformed scale
  plotBestFit_Dietary_BoxCox()

  # --- BC-TRANSFORMED CONFIDENCE LIMITS ----------
  
  # Bayesian bootstrap for BC-transformed fit
  bootModel_Dietary_BoxCox()
  
  # scatter plot bootstrap param
  # print(qplot(BMF.ParamBoot.BoxCox$k2.boot.bc, BMF.ParamBoot.BoxCox$c0d.boot.bc))
  
  # print(summary(BMF.ParamBoot.BoxCox$c0d.boot.bc))
  # print(summary(BMF.ParamBoot.BoxCox$k2.boot.bc))
  
  # prep lower and upper confidence limits of fit
  runConfFit_Dietary_BoxCox()
  
  # plot them in BC-transformed space
  plotConfFit_Dietary_BoxCox()
  
  
  # plot best BC-fit on original scale
  plotInvBestFit_Dietary_BoxCox()
 
  # plot on original untransformed scale
  plotInvConfFit_Dietary_BoxCox()
  
  
  # --- SHOW BMF SUMMARY TABLE (BC-FIT)

  # Test Parameters
  cat("\nDIETARY TEST PARAMETERS:\n\n")
  print(TEST.Dietary.Param)

  # BMF summary Table for BC-transformed fit
  cat("\nBoxCox-TRANSFORMED SUMMARY TABLE:\n\n")
  print(summaryTable_Dietary_BoxCox(digits = 5))

  cat("\n(End of RUN_Dietary_BoxCox)\n\n")

}

##############################
